@@ -15,11 +15,6 @@ typedef struct {
 	const struct rc { /* rc */
 		RND_CFT_BOOLEAN error_on_bad_cli_files;
 	} rc;
-	const struct { /* TODO: this should be in the corresponding plugin */
-		const struct {
-			RND_CFT_BOOLEAN laser;         /* Import g-code assuming laser plotting: M3/M4 is laser on, M5 is laser off */
-		} import_gcode;
-	} plugins;
 } conf_core_t;
 
 
