@@ -31,11 +31,11 @@
 #include "camv_typedefs.h"
 #include <librnd/core/hidlib.h>
 #include <librnd/core/color.h>
-#include "genvector/vtp0.h"
+#include <genvector/vtp0.h>
 #include "rtree.h"
 
 struct camv_design_s {
-	rnd_hidlib_t hidlib; /* shall be the first */
+	rnd_design_t hidlib; /* shall be the first */
 
 	/* UI states */
 	rnd_coord_t crosshair_x, crosshair_y;
