@@ -29,7 +29,7 @@
 #include "obj_arc.h"
 #include "obj_any.h"
 
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include "geo.h"
 #include <gengeo2d/carc.h>
 
