@@ -30,7 +30,7 @@
 #include <librnd/core/global_typedefs.h>
 #include "camv_typedefs.h"
 #include "rtree.h"
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 
 typedef enum camv_objtype_e {
 	CAMV_OBJ_invalid,
