@@ -31,7 +31,7 @@
 #include "geo.h"
 #include <gengeo2d/cline.h>
 
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 
 static void camv_line_free_fields(camv_any_obj_t *obj)
 {
