@@ -34,9 +34,9 @@
 #include <gengeo2d/box.h>
 #include "obj_poly.h"
 
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include <librnd/core/compat_misc.h>
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include "ttf2bbox/ttf2bbox.h"
 
 static ttf2bbox_t ttf;
@@ -103,7 +103,7 @@ void camv_text_update_color(camv_text_t *text, camv_layer_t *ly)
 	}
 }
 
-void camv_text_update(rnd_hidlib_t *hidlib, camv_text_t *text, camv_layer_t *ly)
+void camv_text_update(rnd_design_t *hidlib, camv_text_t *text, camv_layer_t *ly)
 {
 	long tox, toy, sx, sy;
 
@@ -169,7 +169,7 @@ static int camv_text_isc_box(const camv_any_obj_t *o, const camv_rtree_box_t *bo
 
 	return 0;
 
-	TODO("geo: copy the code from pcb-rnd for calculating the corners; need to move mx tranform code from pcb-rnd code to librnd");
+	TODO("TODO: text may be rotated; use rotated box; see sch-rnd text_isc_with_box() triangle tests");
 	return camv_poly_isc_box(&op, box);
 }
 
