@@ -30,6 +30,7 @@
 #include <genvector/vtp0.h>
 
 #include <librnd/core/error.h>
+#include <librnd/core/event.h>
 #include <librnd/core/safe_fs.h>
 
 #include "plug_io.h"
@@ -75,8 +76,10 @@ void camv_io_unreg(camv_io_t *io)
 static void post_load(camv_design_t *camv)
 {
 	camv_data_bbox(camv);
-	camv->hidlib.size_x = camv->bbox.x2;
-	camv->hidlib.size_y = camv->bbox.y2;
+	camv->hidlib.dwg.X1 = camv->bbox.x1;
+	camv->hidlib.dwg.Y1 = camv->bbox.y1;
+	camv->hidlib.dwg.X2 = camv->bbox.x2;
+	camv->hidlib.dwg.Y2 = camv->bbox.y2;
 }
 
 int camv_io_load(camv_design_t *camv, const char *fn)
@@ -99,8 +102,14 @@ int camv_io_load(camv_design_t *camv, const char *fn)
 			continue;
 		rewind(f);
 		if ((io->test_load == NULL) || (io->test_load(camv, fn, f) != 0)) {
+			int res; 
 			rewind(f);
-			if (io->load(camv, fn, f) == 0) {
+
+			rnd_event(&camv->hidlib, RND_EVENT_LOAD_PRE, "s", fn);
+			res = io->load(camv, fn, f);
+			rnd_event(&camv->hidlib, RND_EVENT_LOAD_POST, "si", fn, res);
+
+			if (res == 0) {
 				fclose(f);
 				post_load(camv);
 				return 0;
