@@ -33,8 +33,9 @@
 
 #include "event.h"
 #include <librnd/core/actions.h>
+#include <librnd/hid/hid.h>
 #include <librnd/core/hidlib.h>
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/compat_fs.h>
 #include <librnd/core/globalconst.h>
@@ -146,14 +147,14 @@ static fgw_error_t camv_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* Called with both function and file name -> no gui */
 	if (argc > 2)
-		return RND_ACT_CALL_C(RND_ACT_HIDLIB, camv_act_LoadFrom, res, argc, argv);
+		return RND_ACT_CALL_C(RND_ACT_DESIGN, camv_act_LoadFrom, res, argc, argv);
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, Load, function = argv[1].val.str);
 
 	if (rnd_strcasecmp(function, "Layer") == 0)
-		name = rnd_gui->fileselect(rnd_gui, "Load layer", "Import a layer from file", last_layer, NULL, NULL, "layer", RND_HID_FSD_READ, NULL);
+		name = rnd_hid_fileselect(rnd_gui, "Load layer", "Import a layer from file", last_layer, NULL, NULL, "layer", RND_HID_FSD_READ, NULL);
 	else if (rnd_strcasecmp(function, "Project") == 0)
-		name = rnd_gui->fileselect(rnd_gui, "Load a project file", "load project (all layers) from file", last_project, ".lht", NULL, "project", RND_HID_FSD_READ, NULL);
+		name = rnd_hid_fileselect(rnd_gui, "Load a project file", "load project (all layers) from file", last_project, ".lht", NULL, "project", RND_HID_FSD_READ, NULL);
 	else {
 		rnd_message(RND_MSG_ERROR, "Invalid subcommand for Load(): '%s'\n", function);
 		RND_ACT_IRES(1);
@@ -185,11 +186,13 @@ void pplg_uninit_gui(void)
 {
 	rnd_actionl("rnd_toolbar_uninit", NULL);
 	rnd_event_unbind_allcookie(status_cookie);
+	rnd_event_unbind_allcookie(layersel_cookie);
 	rnd_conf_hid_unreg(status_cookie);
 	rnd_conf_hid_unreg(status_cookie2);
+	rnd_remove_actions_by_cookie(camv_gui_cookie);
 }
 
-static rnd_conf_hid_id_t install_events(const char *cookie, const char *paths[], rnd_conf_hid_callbacks_t cb[], void (*update_cb)(rnd_conf_native_t*,int))
+static rnd_conf_hid_id_t install_events(const char *cookie, const char *paths[], rnd_conf_hid_callbacks_t cb[], void (*update_cb)(rnd_conf_native_t*,int,void*))
 {
 	const char **rp;
 	rnd_conf_native_t *nat;
