@@ -32,14 +32,14 @@
 #include <genvector/vti0.h>
 #include <genvector/vtp0.h>
 
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include <librnd/core/hid_cfg.h>
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 
 #include <librnd/core/actions.h>
 #include "data.h"
 #include "event.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include "layersel.h"
 
@@ -461,7 +461,7 @@ static void layersel_build(void)
 	}
 }
 
-void camv_layersel_gui_init_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+void camv_layersel_gui_init_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if ((RND_HAVE_GUI_ATTR_DLG) && (rnd_gui->get_menu_cfg != NULL)) {
 		layersel.camv = &camv;
@@ -469,14 +469,14 @@ void camv_layersel_gui_init_ev(rnd_hidlib_t *hidlib, void *user_data, int argc,
 	}
 }
 
-void camv_layersel_vis_chg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+void camv_layersel_vis_chg_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if ((!layersel.sub_inited) || (layersel.lock_vis > 0))
 		return;
 	layersel_update_vis(&layersel, &camv);
 }
 
-void camv_layersel_layer_chg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+void camv_layersel_layer_chg_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if ((RND_HAVE_GUI_ATTR_DLG) && (rnd_gui->get_menu_cfg != NULL) && (layersel.sub_inited)) {
 		rnd_hid_dock_leave(&layersel.sub);
