@@ -363,7 +363,7 @@ static int tdx_open_write_header(camv_design_t *camv, write_ctx_t *ctx, const ch
 {
 	rnd_printf_slot[4] = "%.06mm";
 	ctx->camv = camv;
-	ctx->f = rnd_fopen((rnd_hidlib_t *)ctx->camv, fn, "w");
+	ctx->f = rnd_fopen((rnd_design_t *)ctx->camv, fn, "w");
 	ctx->err = 0;
 	if (ctx->f == NULL) {
 		rnd_message(RND_MSG_ERROR, "Can not open '%s' for write\n", fn);
