@@ -6,15 +6,15 @@
 #include "obj_any.h"
 #include "obj_line.h"
 #include "obj_text.h"
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_inlines.h>
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/misc_util.h>
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 camv_tool_mline_t camv_tool_mline;
 
-static void create_mline(rnd_hidlib_t *hl)
+static void create_mline(rnd_design_t *hl)
 {
 	camv_any_obj_t *o;
 	camv_design_t *camv = (camv_design_t *)hl;
@@ -47,11 +47,11 @@ static void tool_mline_uninit(void)
 {
 }
 
-static void tool_mline_press(rnd_hidlib_t *hl)
+static void tool_mline_press(rnd_design_t *hl)
 {
 }
 
-static void tool_mline_release(rnd_hidlib_t *hl)
+static void tool_mline_release(rnd_design_t *hl)
 {
 	switch(camv_tool_mline.clicked) {
 		case 0:
@@ -68,7 +68,7 @@ static void tool_mline_release(rnd_hidlib_t *hl)
 	}
 }
 
-static void tool_mline_adjust_attached_objects(rnd_hidlib_t *hl)
+static void tool_mline_adjust_attached_objects(rnd_design_t *hl)
 {
 	if (camv_tool_mline.clicked == 1) {
 		camv_tool_mline.x2 = camv.crosshair_x;
@@ -77,7 +77,7 @@ static void tool_mline_adjust_attached_objects(rnd_hidlib_t *hl)
 }
 
 
-static void tool_mline_draw_attached(rnd_hidlib_t *hl)
+static void tool_mline_draw_attached(rnd_design_t *hl)
 {
 	rnd_hid_set_line_cap(camv_crosshair_gc, rnd_cap_round);
 	rnd_hid_set_line_width(camv_crosshair_gc, -1);
@@ -90,12 +90,12 @@ static void tool_mline_draw_attached(rnd_hidlib_t *hl)
 	}
 }
 
-rnd_bool tool_mline_undo_act(rnd_hidlib_t *hl)
+rnd_bool tool_mline_undo_act(rnd_design_t *hl)
 {
 	return 0;
 }
 
-rnd_bool tool_mline_redo_act(rnd_hidlib_t *hl)
+rnd_bool tool_mline_redo_act(rnd_design_t *hl)
 {
 	return 0;
 }
